aboutsummaryrefslogtreecommitdiff
path: root/product/sgm775
diff options
context:
space:
mode:
authorLuca Vizzarro <Luca.Vizzarro@arm.com>2020-08-04 18:10:59 +0100
committerChris Kay <chris@cjkay.com>2020-08-14 16:01:42 +0100
commitb434cb612b27677ce73f53c290d59b05b1e6bce3 (patch)
tree8dfcc50ed4bee28429610d203097f0f3d52b477e /product/sgm775
parent0f6486aaf53fdb75d25c96a095f3cae7d646d7ee (diff)
mod_scmi: Adapt available protocols
Originally the command BASE_DISCOVER_LIST_PROTOCOLS of the base SCMI protocol would always return all the implemented SCMI protocols. Through the use of the resource management module, the output can now vary according to the agent's level of access. In this commit the PSCI agent level of access has now been changed to the system power managament protocol only. Change-Id: I80a9f6bb1746b62b171232b977abdb1f10d8de63 Signed-off-by: Luca Vizzarro <Luca.Vizzarro@arm.com>
Diffstat (limited to 'product/sgm775')
-rw-r--r--product/sgm775/scp_ramfw/config_resource_perms.c26
1 files changed, 15 insertions, 11 deletions
diff --git a/product/sgm775/scp_ramfw/config_resource_perms.c b/product/sgm775/scp_ramfw/config_resource_perms.c
index 3ecc2b18..5f82a35c 100644
--- a/product/sgm775/scp_ramfw/config_resource_perms.c
+++ b/product/sgm775/scp_ramfw/config_resource_perms.c
@@ -24,17 +24,21 @@
#define AGENT_IDX(agent_id) (agent_id - 1)
-static struct mod_res_agent_protocol_permissions
- agent_protocol_permissions[] = {
- [AGENT_IDX(SCMI_AGENT_ID_OSPM)] = {
- .protocols = MOD_RES_PERMS_SCMI_ALL_PROTOCOLS_ALLOWED,
- },
-
- /* PSCI agent has no access to clock protocol */
- [AGENT_IDX(SCMI_AGENT_ID_PSCI)] = {
- .protocols = MOD_RES_PERMS_SCMI_CLOCK_PROTOCOL_DENIED,
- },
-};
+static struct mod_res_agent_protocol_permissions agent_protocol_permissions[] =
+ {
+ [AGENT_IDX(SCMI_AGENT_ID_OSPM)] =
+ {
+ .protocols = MOD_RES_PERMS_SCMI_ALL_PROTOCOLS_ALLOWED,
+ },
+
+ /* PSCI agent has no access to clock, perf and sensor protocol */
+ [AGENT_IDX(SCMI_AGENT_ID_PSCI)] =
+ {
+ .protocols = MOD_RES_PERMS_SCMI_CLOCK_PROTOCOL_DENIED |
+ MOD_RES_PERMS_SCMI_PERF_PROTOCOL_DENIED |
+ MOD_RES_PERMS_SCMI_SENSOR_PROTOCOL_DENIED,
+ },
+ };
/*
* Messages have an index offset from 0x3 as all agents can access